# Change log

## 0.4.0

2021-01-13

* Drop support for Python 3.5 and add support for Python 3.9.
* Add support for Django 3.1.


## 0.3.0

2020-03-08

* Drop support for Python 2.7 and 3.4 and add support for Python 3.8.
* Drop support for Django 2.1 and add support for Django 2.2 and 3.0.
* Move to the Gorilla Development group at GitLab.com.


## 0.2.1

2018-12-20

* Removed an unintenional dependency on libgdal (issue #4).


## 0.2.0

2018-10-28

* Moved repo to gitlab.com and set up CI.
* Documented that there is a transactional_ifactory fixture as well.
* Added support for GeoDjango's geometry fields.


## 0.1.0

2018-08-10

* Initial release.
